==> parodia_admin-1.0.2.tar.gz: lib/core/repository/stockList.repository.dart <==
// GET
// /api/v1/dashboard/stocks/lists/{id}

// GET
// /api/v1/dashboard/stocks/lists

// PUT
// /api/v1/dashboard/stocks/lists/fix

import 'package:parodia_admin/core/dto/response_item.dto.dart';
import 'package:parodia_admin/core/dto/response_list.dto.dart';
import 'package:parodia_admin/core/dto/stock_list.dto.dart';
import 'package:parodia_admin/core/enums.dart';
import 'package:parodia_admin/core/http/parodia_http.dart';
import 'package:parodia_admin/core/model/body_data.model.dart';
import 'package:parodia_admin/core/model/query.model.dart';

class StockListRepository {
  ParodiaHTTP? _http;

  StockListRepository(ParodiaHTTP http) {
    _http = http;
  }

  Future<ResponseItemDTO<StockListDTO>> getById({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.get,
      path: '/stocks/lists',
      param: id,
    );

    return ResponseItemDTO<StockListDTO>(
      response: response,
      fromJson: StockListDTO.fromJson,
    );
  }

  Future<ResponseListDTO<StockListDTO>> get({ProductPriceAndRatingQuery? query}) async {
    final response = await _http!.request(
      requestType: RequestType.get,
      path: '/stocks/lists',
      query: query,
    );

    return ResponseListDTO<StockListDTO>(
      response: response,
      fromJson: StockListDTO.fromJson,
    );
  }

  Future<ResponseItemDTO> fix({StockListPutBody? stockList}) async {
    final response = await _http!.request(
      requestType: RequestType.put,
      path: '/stocks/lists/fix',
      data: stockList,
    );

    return ResponseItemDTO(
      response: response,
    );
  }
}

==> parodia_admin-1.0.20.tar.gz: lib/core/repository/stockList.repository.dart <==
// GET
// /api/v1/dashboard/dashboard/stocks/lists/{id}

// GET
// /api/v1/dashboard/dashboard/stocks/lists

// PUT
// /api/v1/dashboard/dashboard/stocks/lists/fix

import 'package:parodia_admin/core/dto/response_item.dto.dart';
import 'package:parodia_admin/core/dto/response_list.dto.dart';
import 'package:parodia_admin/core/dto/stock_list.dto.dart';
import 'package:parodia_admin/core/enums.dart';
import 'package:parodia_admin/core/http/parodia_http.dart';
import 'package:parodia_admin/core/model/body_data.model.dart';
import 'package:parodia_admin/core/model/query.model.dart';

class StockListRepository {
  ParodiaHTTP? _http;

  StockListRepository(ParodiaHTTP http) {
    _http = http;
  }

  Future<ResponseItemDTO<StockListDTO>> getById({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.get,
      path: '/dashboard/stocks/lists',
      param: id,
    );

    return ResponseItemDTO<StockListDTO>(
      response: response,
      fromJson: StockListDTO.fromJson,
    );
  }

  Future<ResponseListDTO<StockListDTO>> get({ProductPriceAndRatingQuery? query}) async {
    final response = await _http!.request(
      requestType: RequestType.get,
      path: '/dashboard/stocks/lists',
      query: query,
    );

    return ResponseListDTO<StockListDTO>(
      response: response,
      fromJson: StockListDTO.fromJson,
    );
  }

  Future<ResponseItemDTO> fix({StockListPutBody? stockList}) async {
    final response = await _http!.request(
      requestType: RequestType.put,
      path: '/dashboard/stocks/lists/fix',
      data: stockList,
    );

    return ResponseItemDTO(
      response: response,
    );
  }
}
